@@ -1,11 +1,12 @@
 import socket
 import time
+from struct import pack
 
 HOST = '35.235.69.154'
 PORT = 61135
 
 
-def request(op: str, value: str = None) -> None:
+def request(op: str, value: str = None) -> str:
     """Sends a TCP request to the server with a packet containing the desired operation and value to be added
 
     Args:
@@ -14,10 +15,11 @@ def request(op: str, value: str = None) -> None:
     """
     with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
         s.connect((HOST, PORT))
-        s.sendall(bytes(str((op, value)), encoding='utf8'))
+        data = bytes(str((op, value)), encoding='utf8')
+        size = pack('>Q', len(data))
+        s.sendall(size)
+        s.sendall(data)
         data = s.recv(1024).decode('utf8')
 
-    print(data)
-    time.sleep(0.5)
-    print('\n\n')
+    return data
 
